$AssetsIconsGen class

Constructors

$AssetsIconsGen()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
infoFill SvgGenImage
File path: assets/icons/info_fill.svg
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successFill SvgGenImage
File path: assets/icons/success_fill.svg
no setter
values List<SvgGenImage>
List of all assets
no setter
warningFill SvgGenImage
File path: assets/icons/warning_fill.svg
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited