LottieGenImage class

Constructors

LottieGenImage(String _assetName, {Set<String> flavors = const {}})
const

Properties

flavors Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
keyName String
no setter
path String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lottie({Animation<double>? controller, bool? animate, FrameRate? frameRate, bool? repeat, bool? reverse, LottieDelegates? delegates, LottieOptions? options, void onLoaded(LottieComposition)?, LottieImageProviderFactory? imageProviderFactory, Key? key, AssetBundle? bundle, Widget frameBuilder(BuildContext, Widget, LottieComposition?)?, ImageErrorWidgetBuilder? errorBuilder, double? width, double? height, BoxFit? fit, AlignmentGeometry? alignment, String? package, bool? addRepaintBoundary, FilterQuality? filterQuality, void onWarning(String)?, LottieDecoder? decoder, RenderCache? renderCache, bool? backgroundLoading}) → LottieBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited